aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--oni-core.el6
1 files changed, 4 insertions, 2 deletions
diff --git a/oni-core.el b/oni-core.el
index 4f67256..0768e91 100644
--- a/oni-core.el
+++ b/oni-core.el
@@ -4,8 +4,8 @@
;; Author: Tom Willemse <tom@ryuslash.org>
;; Keywords: local
;; Version: 2021.1123.003634
;; Package-Requires: (oni-data-dir oni-embrace oni-hydra expand-region multiple-cursors gcmh diminish ws-butler which-key insert-char-preview dashboard mixed-pitch)
;; This program is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published by
@@ -219,6 +219,8 @@ _s_: String list"
(global-set-key (kbd "C-<left>") 'winner-undo)
(global-set-key (kbd "C-<right>") 'winner-redo)
+(global-set-key (kbd "M-o") 'ace-window)
+
(unless oni-core--recentf-idle-timer
(setq oni-core--recentf-idle-timer
(run-with-idle-timer 10 t #'oni-core-recentf-save-list-silently)))
@@ -4,8 +4,8 @@
;; Author: Tom Willemse <tom@ryuslash.org>
;; Keywords: local
-;; Version: 2021.1123.003634
-;; Package-Requires: (oni-data-dir oni-embrace oni-hydra expand-region multiple-cursors gcmh diminish ws-butler which-key insert-char-preview dashboard mixed-pitch)
+;; Version: 2021.1205.144437
+;; Package-Requires: (oni-data-dir oni-embrace oni-hydra expand-region multiple-cursors gcmh diminish ws-butler which-key insert-char-preview dashboard mixed-pitch ace-window)
;; This program is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published by